@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2023 Free Software Foundation, Inc.
+  Copyright (C) 1995-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -53,6 +53,9 @@
 #include <setjmp.h>
 #include <progname.h>
 
+/* For in_port_t.  */
+#include <netinet/in.h>
+
 #ifndef FTP_EXTERN
 # define FTP_EXTERN extern
 #endif
