@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1994-2023 Free Software Foundation, Inc.
+  Copyright (C) 1994-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -115,11 +115,6 @@
 # define MAP_FAILED (void*)-1
 #endif
 
-#if !HAVE_DECL_FCLOSE
-/* Some systems don't declare fclose in <stdio.h>, so do it ourselves.  */
-extern int fclose (FILE *);
-#endif
-
 /* Exported to ftpcmd.h.  */
 struct sockaddr_storage data_dest;	/* Data port.  */
 socklen_t data_dest_len;
@@ -1441,14 +1436,14 @@ send_data (FILE *instr, FILE *outstr, off_t blksize)
 	    syslog (LOG_DEBUG, "Starting at position %jd.", curpos);
 	}
 
-      buf = malloc ((u_int) blksize);
+      buf = malloc ((unsigned int) blksize);
       if (buf == NULL)
 	{
 	  transflag = 0;
 	  perror_reply (451, "Local resource failure: malloc");
 	  return;
 	}
-      while ((cnt = read (filefd, buf, (u_int) blksize)) > 0 &&
+      while ((cnt = read (filefd, buf, (unsigned int) blksize)) > 0 &&
 	     write (netfd, buf, cnt) == cnt)
 	byte_count += cnt;
 
@@ -1499,7 +1494,7 @@ receive_data (FILE *instr, FILE *outstr, off_t blksize)
     {
     case TYPE_I:
     case TYPE_L:
-      buf = malloc ((u_int) blksize);
+      buf = malloc ((unsigned int) blksize);
       if (buf == NULL)
 	{
 	  transflag = 0;
