@@ -1,5 +1,5 @@
 /* printif.c -- print an interface configuration
-  Copyright (C) 2001-2023 Free Software Foundation, Inc.
+  Copyright (C) 2001-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -1125,8 +1125,7 @@ print_interfaceX (format_data_t form, int quiet)
 	  else
 	    {
 	      int argc = 0;
-	      char **argv;
-	      argv = alloca (strlen (q) / 2);
+	      char **argv = NULL;
 
 	      while (*p == '{')
 		{
@@ -1134,6 +1133,7 @@ print_interfaceX (format_data_t form, int quiet)
 		  form->format = p;
 		  print_interfaceX (form, 1);
 		  q = form->format;
+		  argv = xrealloc (argv, (argc + 1) * sizeof (char *));
 		  argv[argc] = xmalloc (q - p + 1);
 		  memcpy (argv[argc], p, q - p);
 		  argv[argc][q - p] = '\0';
@@ -1144,11 +1144,14 @@ print_interfaceX (format_data_t form, int quiet)
 		}
 
 	      format_handler (id, form, argc, argv);
-
-	      /* Clean up.  */
+	      if (argv != NULL)
+		{
+		  /* Clean up.  */
+		  while (--argc >= 0)
+		    free (argv[argc]);
+		  free (argv);
+		}
 	      form->format = p;
-	      while (--argc >= 0)
-		free (argv[argc]);
 	    }
 	}
     }
