@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
-  2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021
-  Free Software Foundation, Inc.
+  Copyright (C) 2001-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -36,7 +34,7 @@
 # elif defined __OpenBSD__
 #  define IU_BSD_TYPE "openbsd"
 #  define ETHERNAME "lladdr"
-# else /* Exotic BSD versions.  */
+# else/* Exotic BSD versions.  */
 #  define IU_BSD_TYPE "unknownbsd"
 # endif
 
@@ -122,8 +120,5 @@ _IU_EXTRN (rx_dropped)
 _IU_EXTRN (tx_dropped)
 _IU_EXTRN (rx_errors)
 _IU_EXTRN (tx_errors)
-_IU_EXTRN (rx_packets)
-_IU_EXTRN (tx_packets)
-_IU_EXTRN (collisions)
-
+_IU_EXTRN (rx_packets) _IU_EXTRN (tx_packets) _IU_EXTRN (collisions)
 #endif /* IFCONFIG_SYSTEM_BSD_H */
