@@ -1,5 +1,5 @@
 /* Substitute for and wrapper around <pty.h>.
-   Copyright (C) 2010-2023 Free Software Foundation, Inc.
+   Copyright (C) 2010-2024 Free Software Foundation, Inc.
 
    This file is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
@@ -44,16 +44,14 @@
 # include <libutil.h>
 #endif
 
-/* Get 'struct termios' and 'struct winsize'.  */
+/* Get 'struct termios', if available, and 'struct winsize'.  */
 #include <termios.h>
 #if defined _AIX
 # include <sys/ioctl.h>
 #endif
-/* Mingw lacks 'struct termios' and 'struct winsize', but a forward
-   declaration of an opaque type is sufficient to allow compilation of
-   a stub openpty().  */
+/* Mingw lacks 'struct termios', but a forward declaration of an opaque type is
+   sufficient to allow compilation of a stub openpty().  */
 struct termios;
-struct winsize;
 
 /* The definitions of _GL_FUNCDECL_RPL etc. are copied here.  */
 
