@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2001-2023 Free Software Foundation, Inc.
+  Copyright (C) 2001-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -24,7 +24,7 @@
 unsigned short
 icmp_cksum (unsigned char *addr, int len)
 {
-  register int sum = 0;
+  int sum = 0;
   unsigned short answer = 0;
   unsigned short *wp;
 
