@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1996-2022 Free Software Foundation, Inc.
+  Copyright (C) 1996-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -71,11 +71,11 @@ static char *normalize_path (char *path, const char *delim);
  * ignored (exclusive-use, lack of permission, etc.).
  */
 char *
-ttymsg (struct iovec *iov, int iovcnt, char *line, int tmout)
+inetutils_ttymsg (struct iovec *iov, int iovcnt, char *line, int tmout)
 {
   static char errbuf[MAX_ERRBUF];
   char *device;
-  register int cnt, fd, left, wret;
+  int cnt, fd, left, wret;
   struct iovec localiov[6];
   int forked = 0;
 
@@ -180,7 +180,7 @@ ttymsg (struct iovec *iov, int iovcnt, char *line, int tmout)
 #else
 	  sigsetmask (0);
 #endif
-	  alarm ((u_int) tmout);
+	  alarm ((unsigned int) tmout);
 	  fcntl (fd, O_NONBLOCK, &off);
 	  continue;
 	}
