@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2009-2022 Free Software Foundation, Inc.
+  Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -16,6 +16,6 @@
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
-int isprefix (register char *s1, register char *s2);
+int isprefix (char *s1, char *s2);
 char **genget (char *name, char **table, int stlen);
 int Ambiguous (char *s);
