@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1993-2023 Free Software Foundation, Inc.
+  Copyright (C) 1993-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -127,7 +127,7 @@ kerberos5_init (TN_Authenticator *ap MAYBE_UNUSED, int server)
 }
 
 void
-kerberos5_cleanup ()
+kerberos5_cleanup (void)
 {
   krb5_ccache ccache;
   char *ccname;
