@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2005-2022 Free Software Foundation, Inc.
+  Copyright (C) 2005-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -27,5 +27,5 @@ static int ping_set_dest (PING * ping, const char *host);
 static int ping_recv (PING * p);
 static int ping_xmit (PING * p);
 
-static int ping_run (PING * ping, int (*finish) ());
+static int ping_run (PING * ping, int (*finish) (void));
 static int ping_finish (void);
