@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2001-2023 Free Software Foundation, Inc.
+  Copyright (C) 2001-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -26,7 +26,7 @@ extern PING *ping;
 extern unsigned char *data_buffer;
 extern size_t data_length;
 
-extern int ping_run (PING * ping, int (*finish) ());
+extern int ping_run (PING * ping, int (*finish) (void));
 extern int ping_finish (void);
 extern void print_icmp_header (struct sockaddr_in *from,
 			       struct ip *ip, icmphdr_t * icmp, int len);
