@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2023 Free Software Foundation, Inc.
+  Copyright (C) 1995-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -203,7 +203,7 @@ void copytochild (int);
 void doit (sigset_t *);
 void done (int);
 void echo (char);
-u_int getescape (char *);
+unsigned int getescape (char *);
 void lostpeer (int);
 void mode (int);
 void oob (int);
@@ -980,7 +980,7 @@ catch_child (int signo MAYBE_UNUSED)
 void
 writer (void)
 {
-  register int bol, local, n;
+  int bol, local, n;
   char c;
 
   bol = 1;			/* beginning of line */
@@ -1083,9 +1083,9 @@ writer (void)
 }
 
 void
-echo (register char c)
+echo (char c)
 {
-  register char *p;
+  char *p;
   char buf[8];
 
   p = buf;
@@ -1455,15 +1455,15 @@ get_window_size (int fd, struct winsize *wp)
 }
 #endif
 
-u_int
-getescape (register char *p)
+unsigned int
+getescape (char *p)
 {
   long val;
   int len;
 
   len = strlen (p);
   if (len == 1)			/* use any single char, including '\'.  */
-    return ((u_int) * p);
+    return ((unsigned int) *p);
 
   /* otherwise, \nnn */
   if (*p == '\\' && len >= 2 && len <= 4)
@@ -1472,7 +1472,7 @@ getescape (register char *p)
       for (;;)
 	{
 	  if (!*++p)
-	    return ((u_int) val);
+	    return ((unsigned int) val);
 	  if (*p < '0' || *p > '8')
 	    break;
 	}
