@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1993-2023 Free Software Foundation, Inc.
+  Copyright (C) 1993-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -103,8 +103,6 @@ char *nenv[] = {
   NULL,
 };
 
-extern char **environ;
-
 static struct argp_option argp_options[] = {
 #define GRP 10
   {"uucico", 'u', "LOCATION", 0,
@@ -168,7 +166,7 @@ main (int argc, char **argv)
 }
 
 static int
-readline (register char *p, register int n)
+readline (char *p, int n)
 {
   char c;
 
