@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2023 Free Software Foundation, Inc.
+  Copyright (C) 1995-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -74,7 +74,7 @@ net_write (unsigned char *str, int len)
 }
 
 void
-net_encrypt ()
+net_encrypt (void)
 {
 # ifdef	ENCRYPTION
   if (encrypt_output)
@@ -85,7 +85,7 @@ net_encrypt ()
 }
 
 int
-telnet_spin ()
+telnet_spin (void)
 {
   return (-1);
 }
@@ -99,9 +99,6 @@ telnet_getenv (char *val)
 char *
 telnet_gets (char *prompt, char *result, int length, int echo)
 {
-# if !HAVE_DECL_GETPASS
-  extern char *getpass ();
-# endif
   extern int globalmode;
   int om = globalmode;
   char *res;
