@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2023 Free Software Foundation, Inc.
+  Copyright (C) 1995-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -149,7 +149,7 @@ setneturg (void)
 int
 netflush (void)
 {
-  register int n, n1;
+  int n, n1;
 
 #ifdef	ENCRYPTION
   if (encrypt_output)
