@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2023 Free Software Foundation, Inc.
+  Copyright (C) 1995-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -327,7 +327,7 @@ ring_supply_data (Ring *ring, unsigned char *buffer, int count)
 
 #ifdef	ENCRYPTION
 void
-ring_encrypt (Ring *ring, void (*encryptor) ())
+ring_encrypt (Ring *ring, void (*encryptor) (unsigned char *, int))
 {
   unsigned char *s, *c;
 
