@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2023 Free Software Foundation, Inc.
+  Copyright (C) 1995-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -70,10 +70,13 @@
 #include "types.h"
 
 #ifdef	SIGINFO
-extern void ayt_status ();
-extern void sendayt ();
+extern void ayt_status (void);
+extern void sendayt (void);
 #endif
 
+void susp (int sig);
+void ayt (int sig);
+
 int tout,			/* Output file descriptor */
   tin,				/* Input file descriptor */
   net;
@@ -297,7 +300,7 @@ TerminalSaveState (void)
 }
 
 cc_t *
-tcval (register int func)
+tcval (int func)
 {
   switch (func)
     {
@@ -412,7 +415,7 @@ TerminalDefaultChars (void)
 
 
 void
-TerminalNewMode (register int f)
+TerminalNewMode (int f)
 {
   static int prevmode = 0;
 #ifndef USE_TERMIO
@@ -673,13 +676,6 @@ TerminalNewMode (register int f)
 
   if (f != -1)
     {
-#ifdef	SIGTSTP
-      void susp (int sig);
-#endif /* SIGTSTP */
-#ifdef	SIGINFO
-      void ayt ();
-#endif
-
 #ifdef	SIGTSTP
       signal (SIGTSTP, susp);
 #endif /* SIGTSTP */
@@ -729,9 +725,7 @@ TerminalNewMode (register int f)
   else
     {
 #ifdef	SIGINFO
-      void ayt_status ();
-
-      signal (SIGINFO, ayt_status);
+      signal (SIGINFO, (void (*)(int)) ayt_status);
 #endif
 #ifdef	SIGTSTP
       signal (SIGTSTP, SIG_DFL);
@@ -865,9 +859,9 @@ void
 TerminalSpeeds (long *ispeed, long *ospeed)
 {
 #ifdef	DECODE_BAUD
-  register struct termspeeds *tp;
+  struct termspeeds *tp;
 #endif /* DECODE_BAUD */
-  register long in, out;
+  long in, out;
 
   out = cfgetospeed (&old_tc);
   in = cfgetispeed (&old_tc);
@@ -1070,7 +1064,7 @@ int
 process_rings (int netin, int netout, int netex, int ttyin, int ttyout,
 	       int poll)
 {
-  register int c;
+  int c;
   /* One wants to be a bit careful about setting returnValue
    * to one, since a one implies we did some useful work,
    * and therefore probably won't be called to block next
