@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2022 Free Software Foundation, Inc.
+  Copyright (C) 1995-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -105,7 +105,7 @@ static unsigned char subbuffer[SUBBUFSIZE], *subpointer, *subend;	/* buffer for
 #define SB_EOF()	(subpointer >= subend)
 #define SB_LEN()	(subend - subpointer)
 
-char options[256] = { 0 };		/* The combined options */
+char options[256] = { 0 };	/* The combined options */
 char do_dont_resp[256] = { 0 };
 char will_wont_resp[256] = { 0 };
 
@@ -176,8 +176,8 @@ int kludgelinemode = 1;
  */
 
 Clocks clocks;
-
-
+
+
 
 /*
  * Initialize telnet environment.
@@ -219,7 +219,7 @@ init_telnet (void)
  */
 
 void
-send_do (register int c, register int init)
+send_do (int c, int init)
 {
   if (init)
     {
@@ -235,7 +235,7 @@ send_do (register int c, register int init)
 }
 
 void
-send_dont (register int c, register int init)
+send_dont (int c, int init)
 {
   if (init)
     {
@@ -251,7 +251,7 @@ send_dont (register int c, register int init)
 }
 
 void
-send_will (register int c, register int init)
+send_will (int c, int init)
 {
   if (init)
     {
@@ -267,7 +267,7 @@ send_will (register int c, register int init)
 }
 
 void
-send_wont (register int c, register int init)
+send_wont (int c, int init)
 {
   if (init)
     {
@@ -590,10 +590,10 @@ dontoption (int option)
 }
 
 int
-is_unique (register char *name, register char **as, register char **ae)
+is_unique (char *name, char **as, char **ae)
 {
-  register char **ap;
-  register int n;
+  char **ap;
+  int n;
 
   n = strlen (name) + 1;
   for (ap = as; ap < ae; ap++)
@@ -615,8 +615,8 @@ static char *unknown[] = { 0, 0 };
 char **
 mklist (char *buf, char *name)
 {
-  register int n;
-  register char c, *cp, **argvp, *cp2, **argv, **avt;
+  int n;
+  char c, *cp, **argvp, *cp2, **argv, **avt;
 
   if (name)
     {
@@ -663,11 +663,11 @@ mklist (char *buf, char *name)
    */
   argvp = argv + 1;
   *argv = *argvp = 0;
-  n = 0;		/* Positive: name uses white space.  */
+  n = 0;			/* Positive: name uses white space.  */
 
   for (cp = cp2 = buf; (c = *cp); cp++)
     {
-      if (c == '|' || c == ':')		/* Delimiters */
+      if (c == '|' || c == ':')	/* Delimiters */
 	{
 	  *cp++ = '\0';
 	  /*
@@ -863,9 +863,7 @@ suboption (void)
 	  if ((len < NETROOM ()) && (len < (int) sizeof (temp)))
 	    {
 	      snprintf ((char *) temp, sizeof (temp), "%c%c%c%c%s%c%c",
-			IAC, SB, TELOPT_TTYPE, TELQUAL_IS,
-			name,
-			IAC, SE);
+			IAC, SB, TELOPT_TTYPE, TELQUAL_IS, name, IAC, SE);
 	      ring_supply_data (&netoring, temp, len);
 	      printsub ('>', &temp[2], len - 2);
 	    }
@@ -890,8 +888,7 @@ suboption (void)
 
 	  snprintf ((char *) temp, sizeof (temp), "%c%c%c%c%d,%d%c%c",
 		    IAC, SB, TELOPT_TSPEED, TELQUAL_IS,
-		    (int) ospeed, (int) ispeed,
-		    IAC, SE);
+		    (int) ospeed, (int) ispeed, IAC, SE);
 	  len = strlen ((char *) temp + 4) + 4;	/* temp[3] is 0 ... */
 
 	  if (len < NETROOM ())
@@ -1020,9 +1017,7 @@ suboption (void)
 
 	  /* Go ahead safely.  */
 	  snprintf ((char *) temp, sizeof (temp), "%c%c%c%c%s%c%c",
-		    IAC, SB, TELOPT_XDISPLOC, TELQUAL_IS,
-		    dp,
-		    IAC, SE);
+		    IAC, SB, TELOPT_XDISPLOC, TELQUAL_IS, dp, IAC, SE);
 	  len = strlen ((char *) temp + 4) + 4;	/* temp[3] is 0 ... */
 
 	  if (len < NETROOM ())
@@ -1279,7 +1274,7 @@ static int slc_mode = SLC_EXPORT;
 void
 slc_init (void)
 {
-  register struct spc *spcp;
+  struct spc *spcp;
 
   localchars = 1;
   for (spcp = spc_data; spcp < &spc_data[NSLC + 1]; spcp++)
@@ -1366,6 +1361,7 @@ slc_mode_import (int def)
 unsigned char slc_import_val[] = {
   IAC, SB, TELOPT_LINEMODE, LM_SLC, 0, SLC_VARIABLE, 0, IAC, SE
 };
+
 unsigned char slc_import_def[] = {
   IAC, SB, TELOPT_LINEMODE, LM_SLC, 0, SLC_DEFAULT, 0, IAC, SE
 };
@@ -1396,7 +1392,7 @@ slc_import (int def)
 void
 slc_export (void)
 {
-  register struct spc *spcp;
+  struct spc *spcp;
 
   TerminalDefaultChars ();
 
@@ -1420,10 +1416,10 @@ slc_export (void)
 }
 
 void
-slc (register unsigned char *cp, int len)
+slc (unsigned char *cp, int len)
 {
-  register struct spc *spcp;
-  register int func, level;
+  struct spc *spcp;
+  int func, level;
 
   slc_start_reply ();
 
@@ -1498,7 +1494,7 @@ slc (register unsigned char *cp, int len)
 void
 slc_check (void)
 {
-  register struct spc *spcp;
+  struct spc *spcp;
 
   slc_start_reply ();
   for (spcp = &spc_data[1]; spcp < &spc_data[NSLC + 1]; spcp++)
@@ -1532,7 +1528,7 @@ slc_start_reply (void)
 }
 
 void
-slc_add_reply(unsigned int func, unsigned int flags, cc_t value)
+slc_add_reply (unsigned int func, unsigned int flags, cc_t value)
 {
   if ((*slc_replyp++ = func) == IAC)
     *slc_replyp++ = IAC;
@@ -1545,7 +1541,7 @@ slc_add_reply(unsigned int func, unsigned int flags, cc_t value)
 void
 slc_end_reply (void)
 {
-  register int len;
+  int len;
 
   *slc_replyp++ = IAC;
   *slc_replyp++ = SE;
@@ -1565,7 +1561,7 @@ slc_end_reply (void)
 int
 slc_update (void)
 {
-  register struct spc *spcp;
+  struct spc *spcp;
   int need_update = 0;
 
   for (spcp = &spc_data[1]; spcp < &spc_data[NSLC + 1]; spcp++)
@@ -1603,10 +1599,10 @@ int old_env_value = OLD_ENV_VALUE;
 #endif
 
 void
-env_opt (register unsigned char *buf, register int len)
+env_opt (unsigned char *buf, int len)
 {
-  register unsigned char *ep = 0, *epc = 0;
-  register int i;
+  unsigned char *ep = 0, *epc = 0;
+  int i;
 
   switch (buf[0] & 0xff)
     {
@@ -1712,9 +1708,9 @@ env_opt_start_info (void)
 }
 
 void
-env_opt_add (register unsigned char *ep)
+env_opt_add (unsigned char *ep)
 {
-  register unsigned char *vp, c;
+  unsigned char *vp, c;
 
   if (opt_reply == NULL)
      /*XXX*/ return;
@@ -1731,11 +1727,11 @@ env_opt_add (register unsigned char *ep)
 	env_opt_add (ep);
       return;
     }
-  vp = env_getvalue ((char *)ep);
+  vp = env_getvalue ((char *) ep);
   if (opt_replyp + (vp ? strlen ((char *) vp) : 0) +
       strlen ((char *) ep) + 6 > opt_replyend)
     {
-      register int len;
+      int len;
       opt_replyend += OPT_REPLY_SIZE;
       len = opt_replyend - opt_reply;
       opt_reply = (unsigned char *) realloc (opt_reply, len);
@@ -1807,9 +1803,9 @@ opt_welldefined (char *ep)
 }
 
 void
-env_opt_end (register int emptyok)
+env_opt_end (int emptyok)
 {
-  register int len;
+  int len;
 
   if (opt_replyp + 2 > opt_replyend)
     return;
@@ -1839,9 +1835,9 @@ env_opt_end (register int emptyok)
 int
 telrcv (void)
 {
-  register int c;
-  register int scc;
-  register unsigned char *sbp;
+  int c;
+  int scc;
+  unsigned char *sbp;
   int count;
   int returnValue = 0;
 
@@ -1907,7 +1903,7 @@ telrcv (void)
 # ifdef	ENCRYPTION
 		  if (decrypt_input)
 		    c = (*decrypt_input) (c);
-# endif	/* ENCRYPTION */
+# endif/* ENCRYPTION */
 		  if (c == IAC)
 		    {
 		      telrcv_state = TS_IAC;
@@ -2185,8 +2181,8 @@ telsnd (void)
   count = 0;
   while (NETROOM () > 2)
     {
-      register int sc;
-      register int c;
+      int sc;
+      int c;
 
       if (tcc == 0)
 	{
@@ -2479,7 +2475,7 @@ telnet (char *user)
 # ifdef	ENCRYPTION
       send_do (TELOPT_ENCRYPT, 1);
       send_will (TELOPT_ENCRYPT, 1);
-# endif	/* ENCRYPTION */
+# endif/* ENCRYPTION */
       send_do (TELOPT_SGA, 1);
       send_will (TELOPT_TTYPE, 1);
       send_will (TELOPT_NAWS, 1);
@@ -2598,7 +2594,7 @@ nextitem (char *current)
       return current + 3;
     case SB:			/* loop forever looking for the SE */
       {
-	register char *look = current + 2;
+	char *look = current + 2;
 
 	for (;;)
 	  {
@@ -2638,7 +2634,7 @@ static void
 netclear (void)
 {
 #if 0				/* XXX */
-  register char *thisitem, *next;
+  char *thisitem, *next;
   char *good;
 # define wewant(p)	((nfrontp > p) && ((*p&0xff) == IAC) && \
 				((*(p+1)&0xff) != EC) && ((*(p+1)&0xff) != EL))
@@ -2724,7 +2720,7 @@ xmitEC (void)
 
 
 int
-dosynch(const char *s)
+dosynch (const char *s)
 {
   netclear ();			/* clear the path to the network */
   NETADD (IAC);
@@ -2737,10 +2733,10 @@ dosynch(const char *s)
 int want_status_response = 0;
 
 int
-get_status(const char *s)
+get_status (const char *s)
 {
   unsigned char tmp[16];
-  register unsigned char *cp;
+  unsigned char *cp;
 
   if (my_want_state_is_dont (TELOPT_STATUS))
     {
@@ -2776,7 +2772,7 @@ intp (void)
     }
   if (autosynch)
     {
-      dosynch(NULL);
+      dosynch (NULL);
     }
 }
 
@@ -2851,7 +2847,7 @@ sendnaws (void)
 {
   long rows, cols;
   unsigned char tmp[16];
-  register unsigned char *cp;
+  unsigned char *cp;
 
   if (my_state_is_wont (TELOPT_NAWS))
     return;
