@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2022 Free Software Foundation, Inc.
+  Copyright (C) 2002-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -51,7 +51,7 @@ startslave (char *host, int autologin, char *autoname)
       exit (EXIT_FAILURE);
     }
 #else /* !AUTHENTICATION */
-  (void) autoname;	/* Silence warnings.  */
+  (void) autoname;		/* Silence warnings.  */
 #endif
 
   pid = forkpty (&master, line, NULL, NULL);
@@ -83,7 +83,6 @@ startslave (char *host, int autologin, char *autoname)
   return master;
 }
 
-extern char **environ;
 /*
  * scrub_env()
  *
@@ -95,7 +94,7 @@ extern char **environ;
 static void
 scrub_env (void)
 {
-  register char **cpp, **cpp2;
+  char **cpp, **cpp2;
 
   for (cpp2 = cpp = environ; *cpp; cpp++)
     {
@@ -114,7 +113,7 @@ start_login (char *host, int autologin, char *name)
   int argc;
   char **argv;
 
-  (void) host;		/* Silence warnings.  Diagnostic use?  */
+  (void) host;			/* Silence warnings.  Diagnostic use?  */
   (void) autologin;
   (void) name;
 
