@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1996-2023 Free Software Foundation, Inc.
+  Copyright (C) 1996-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -16,7 +16,6 @@
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see `http://www.gnu.org/licenses/'. */
 
-#include <config.h>
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/stat.h>
@@ -276,7 +275,7 @@ void netflush (void);
 int pty_buffer_is_full (void);
 void pty_output_byte (int c);
 void pty_output_datalen (const void *data, size_t len);
-int pty_buffer_level ();
+int pty_buffer_level (void);
 
 /* Debugging functions */
 extern void printoption (char *, int);
@@ -326,7 +325,7 @@ extern void change_slc (char func, char flag, cc_t val);
 
 extern void cleanup (int);
 extern void clientstat (int, int, int);
-extern void copy_termbuf ();
+extern void copy_termbuf (void);
 extern void deferslc (void);
 extern void defer_terminit (void);
 extern void do_opt_slc (unsigned char *, int);
