@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1993-2023 Free Software Foundation, Inc.
+  Copyright (C) 1993-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -422,7 +422,7 @@ flowstat (void)
  * affected.
  */
 void
-clientstat (register int code, register int parm1, register int parm2)
+clientstat (int code, int parm1, int parm2)
 {
   void netflush (void);
 
@@ -505,7 +505,7 @@ clientstat (register int code, register int parm1, register int parm2)
 
     case LM_MODE:
       {
-	register int ack, changed;
+	int ack, changed;
 
 	/*
 	 * Client has sent along a mode mask.  If it agrees with
@@ -647,13 +647,13 @@ clientstat (register int code, register int parm1, register int parm2)
 
 #if defined CRAY2 && defined UNICOS5
 void
-termstat ()
+termstat (void)
 {
   needtermstat = 1;
 }
 
 void
-_termstat ()
+_termstat (void)
 {
   needtermstat = 0;
   init_termbuf ();
