@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1993-2023 Free Software Foundation, Inc.
+  Copyright (C) 1993-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -1640,7 +1640,7 @@ net_write (unsigned char *str, int len)
 }
 
 void
-net_encrypt ()
+net_encrypt (void)
 {
 # ifdef	ENCRYPTION
   char *s = (nclearto > nbackp) ? nclearto : nbackp;
@@ -1651,7 +1651,7 @@ net_encrypt ()
 }
 
 int
-telnet_spin ()
+telnet_spin (void)
 {
   io_drain ();
   return 0;
