@@ -1,5 +1,5 @@
 /* addrpeek - testing service for Inetd: remote address, environment vars
-  Copyright (C) 2010-2023 Free Software Foundation, Inc.
+  Copyright (C) 2010-2024 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -56,13 +56,6 @@
 # define SEPARATOR "\n"
 #endif
 
-/* TODO Develop some reliable test for the existence of ENVIRON.
- * It is detectable using HAVE_DECL_ENVIRON for GNU/Linux and
- * GNU/kFreeBSD. It is present, but not detectable for OpenBSD
- * and FreeBSD.
- */
-extern char **environ;
-
 static void
 write_address (int fd)
 {
