@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2011-2023 Free Software Foundation, Inc.
+# Copyright (C) 2011-2024 Free Software Foundation, Inc.
 #
 # This file is part of GNU Inetutils.
 #
@@ -105,7 +105,7 @@ fi
 
 # Check regression of crash reported here:
 # https://lists.gnu.org/archive/html/bug-inetutils/2022-02/msg00014.html
-echo 'help z ! ? z ! ? z ! ? z ! ? z ! ? z ! ? z !' | $TELNET > /dev/null
+echo 'help z ! ? z ! ? z ! ? z ! ? z ! ? z ! ? z !' | $TELNET > /dev/null 2>&1
 if test $? -ne 0; then
     echo "Regression of telnet crash bug." >&2
     exit 1
@@ -113,7 +113,7 @@ fi
 
 # Check regression of crash reported here:
 # https://lists.gnu.org/archive/html/bug-inetutils/2022-02/msg00009.html
-echo 'help help' | $TELNET > /dev/null
+echo 'help help' | $TELNET > /dev/null 2>&1
 if test $? -ne 0; then
     echo "Regression of telnet second crash bug." >&2
     exit 1
@@ -121,7 +121,7 @@ fi
 
 # Check regression of crash reported here:
 # https://lists.gnu.org/archive/html/bug-inetutils/2022-02/msg00007.html
-echo "unset ' '" | $TELNET > /dev/null
+echo "unset ' '" | $TELNET > /dev/null 2>&1
 if test $? -ne 0; then
     echo "Regression of telnet third crash bug." >&2
     exit 1
@@ -129,12 +129,33 @@ fi
 
 # Check regression of crash reported here:
 # https://lists.gnu.org/archive/html/bug-inetutils/2022-02/msg00010.html
-echo "set ' ' foo" | $TELNET > /dev/null
+echo "set ' ' foo" | $TELNET > /dev/null 2>&1
 if test $? -ne 0; then
     echo "Regression of telnet fourth crash bug." >&2
     exit 1
 fi
 
+errno=0
+
+# In non-verbose mode the variables `display' and `display_err'
+# redirect output streams to `/dev/null'.
+
+test -n "${VERBOSE+yes}" || display='>/dev/null'
+test -n "${VERBOSE+yes}" || display_err='2>/dev/null'
+
+# Check regression of integer overflow check reported in:
+# https://lists.gnu.org/archive/html/bug-inetutils/2024-08/msg00007.html
+for value in -2147483649 -1 256 2147483648 9223372036854775808; do
+    for cmd in "do" "dont" "will" "wont"; do
+        output=`echo "send $cmd $value" | $TELNET 2>&1`
+        echo "$output" | eval "$GREP ': bad value ' $display"
+        if test $? -ne 0; then
+            errno=1
+            echo "Failed to catch bad value '$value'." >&2
+        fi
+    done
+done
+
 # Portability fix for SVR4
 PWD="${PWD:-`pwd`}"
 
@@ -191,13 +212,6 @@ fi
 
 # Must use '-d' consistently to prevent daemonizing, but we
 # would like to suppress the verbose output.
-#
-# In non-verbose mode the variables `display' and `display_err'
-# redirect output streams to `/dev/null'.
-
-test -n "${VERBOSE+yes}" || display='>/dev/null'
-test -n "${VERBOSE+yes}" || display_err='2>/dev/null'
-
 
 eval "$INETD -d -p'$INETD_PID' '$INETD_CONF' $display_err &"
 
@@ -221,8 +235,6 @@ test -z "$VERBOSE" || echo "Launched Inetd as process $inetd_pid." >&2
 
 telnet_opts="--no-rc --no-escape --no-login"
 
-errno=0
-
 if test "$TEST_IPV4" != "no" && test -n "$TARGET"; then
     output=`$TELNET $telnet_opts $TARGET $PORT 2>/dev/null`
     echo "$output" | eval "$GREP 'Your address is $TARGET.' $display"
